Learn R Programming

ConSciR (version 0.3.0)

ConSciR-package: ConSciR: Tools for Conservation Science

Description

logo

Provides data science tools for conservation science, including methods for environmental data analysis, humidity calculations, sustainability metrics, engineering calculations, and data visualisation. Supports conservators, scientists, and engineers working with cultural heritage preventive conservation data. The package is motivated by the framework outlined in Cosaert and Beltran et al. (2022) "Tools for the Analysis of Collection Environments" https://www.getty.edu/conservation/publications_resources/pdf_publications/tools_for_the_analysis_of_collection_environments.html.

Arguments

Author

Maintainer: Bhavesh Shah bhaveshshah01@gmail.com (ORCID) [copyright holder]

Authors:

  • Annelies Cosaert (ORCID)

  • Vincent Beltran

Other contributors:

  • Emily R Long (ORCID) [contributor]

  • Marcin Zygmunt (ORCID) [contributor]

  • Hebe Halstead [contributor]

  • Avery Bazemore (ORCID) [contributor]

See Also