Learn R Programming

ConSciR (version 0.3.0)

calcMR: Calculate Mixing Ratio

Description

Function to calculate mixing ratio (g/kg) from temperature (°C) and relative humidity (%).

Mixing Ratio is the mass of water vapor present in a given volume of air relative to the mass of dry air.

Usage

calcMR(Temp, RH, P_atm = 1013.25, B = 621.9907, ...)

Value

X Mixing ratio, mass of water vapour / mass of dry gas (g/kg)

Arguments

Temp

Temperature (°Celsius)

RH

Relative Humidity (0-100%)

P_atm

Atmospheric pressure = 1013.25 (hPa)

B

B = 621.9907 g/kg for air

...

Additional arguments to supply to calcPws

Details

X Mixing ratio (mass of water vapour / mass of dry gas)

Pw = Pws(40°C) = 73.75 hPa

X = 621.9907 x 73.75 / (998 - 73.75) = 49.63 g/kg

See Also

calcMR for calculating mixing ratio

calcAD for calculating air density

calcPw for calculating water vapour pressure

calcPws for calculating water vapour saturation pressure

Examples

Run this code
# Mixing ratio at 20°C (Temp) and 50% relative humidity (RH)
calcMR(20, 50)

# mydata file
filepath <- data_file_path("mydata.xlsx")
mydata <- readxl::read_excel(filepath, sheet = "mydata", n_max = 5)

mydata |> dplyr::mutate(MixingRatio = calcMR(Temp, RH))


Run the code above in your browser using DataLab