Learn R Programming

ConSciR (version 0.3.0)

calcSensibleHeatRatio: Calculate Sensible Heat Ratio (SHR)

Description

This function calculates the Sensible Heat Ratio (SHR) using the sensible and total heating values.

Sensible heat ratio is the ratio of sensible heat to total heat.

Usage

calcSensibleHeatRatio(Temp1, Temp2, RH1, RH2, volumeFlowRate)

Value

SHR Sensible Heat Ratio (0-100%)

Arguments

Temp1

Initial Temperature (°Celsius)

Temp2

Final Temperature (°Celsius)

RH1

Initial Relative Humidity (0-100%)

RH2

Final Relative Humidity (0-100%)

volumeFlowRate

Volume flow rate of air in cubic meters per second (m³/s)

See Also

calcSensibleHeating, calcTotalHeating

Examples

Run this code
calcSensibleHeatRatio(20, 25, 50, 30, 0.5)


Run the code above in your browser using DataLab