Learn R Programming

ConSciR (version 0.3.0)

run_ConSciR_app: Run the ConSciR Shiny Application

Description

Launch the ConSciR Shiny app which includes tools for temperature and relative humidity monitoring such as TRH charts, psychrometric charts, bivariate plots, mould growth predictions, and a silica gel calculator.

Users can upload CSV or Excel files formatted with "Date", "Temp", and "RH" columns. The app provides data tidying functions and downloadable cleaned CSV files.

The silica gel calculator estimates the required amount of silica gel based on temperature, humidity data, case dimensions, and air exchange rate (AER) if known.

Usage

run_ConSciR_app()

Arguments

Value

A Shiny application object that runs interactively.

Examples

Run this code
if(interactive()) {
    run_ConSciR_app()
}

Run the code above in your browser using DataLab