powered by
This function calculates the Sensible Heat Ratio (SHR) using the sensible and total heating values.
Sensible heat ratio is the ratio of sensible heat to total heat.
calcSensibleHeatRatio(Temp1, Temp2, RH1, RH2, volumeFlowRate)
SHR Sensible Heat Ratio (0-100%)
Initial Temperature (°Celsius)
Final Temperature (°Celsius)
Initial Relative Humidity (0-100%)
Final Relative Humidity (0-100%)
Volume flow rate of air in cubic meters per second (m³/s)
calcSensibleHeating, calcTotalHeating
calcSensibleHeating
calcTotalHeating
calcSensibleHeatRatio(20, 25, 50, 30, 0.5)
Run the code above in your browser using DataLab